pub struct ParserMapT<PType, M> { /* private fields */ }Trait Implementations
Sourceimpl<'a, P, M, I, O, E: ParserError, PType, F> Parser<'a, I, O, E, ParserMapT<PType, M>> for ParserMap<P, I, M, E, F>
impl<'a, P, M, I, O, E: ParserError, PType, F> Parser<'a, I, O, E, ParserMapT<PType, M>> for ParserMap<P, I, M, E, F>
Sourcefn fab(&self, input: &mut &'a I) -> Result<O, E>
fn fab(&self, input: &mut &'a I) -> Result<O, E>
Parses the input. This method advances the input reference to the remaining
unparsed input. The method is named “fab” instead of “parse” to avoid conflicts
with the “parse” method of &str.
Sourcefn fab_value<V: Clone>(self, value: V) -> Value<Self, V, I, O, E>where
Self: Sized,
fn fab_value<V: Clone>(self, value: V) -> Value<Self, V, I, O, E>where
Self: Sized,
Returns a parser that replaces the output of the underlying parser with V.
Sourcefn fab_map<F>(self, func: F) -> ParserMap<Self, I, O, E, F>where
Self: Sized,
fn fab_map<F>(self, func: F) -> ParserMap<Self, I, O, E, F>where
Self: Sized,
This creates a Map parser that applies the function to the
output of the underlying parser.
Sourcefn fab_try_map<F>(self, func: F) -> ParserTryMap<Self, I, O, E, F>where
Self: Sized,
fn fab_try_map<F>(self, func: F) -> ParserTryMap<Self, I, O, E, F>where
Self: Sized,
This parser first maps the input, and if the result is Option::Some or Result::Ok,
it unwraps the input. Othewise, the parser fails.